@@ -264,7 +264,7 @@ function install_redis {
     fi
 
     start_service redis
-
+    redis-cli del octavia_jobboard:listings
 }
 
 function stop_redis {
@@ -289,10 +289,6 @@ function octavia_configure {
     sudo mkdir -m 700 -p $OCTAVIA_RUN_DIR
     safe_chown $STACK_USER $OCTAVIA_RUN_DIR
 
-    if ! [ -e $OCTAVIA_CONF ] ; then
-        cp $OCTAVIA_DIR/etc/octavia.conf $OCTAVIA_CONF
-    fi
-
     if ! [ -e $OCTAVIA_AUDIT_MAP ] ; then
         cp $OCTAVIA_DIR/etc/audit/octavia_api_audit_map.conf.sample $OCTAVIA_AUDIT_MAP
     fi
@@ -332,6 +328,7 @@ function octavia_configure {
     iniset $OCTAVIA_CONF controller_worker network_driver ${OCTAVIA_NETWORK_DRIVER}
     iniset $OCTAVIA_CONF controller_worker image_driver ${OCTAVIA_IMAGE_DRIVER}
     iniset $OCTAVIA_CONF controller_worker amp_image_tag ${OCTAVIA_AMP_IMAGE_TAG}
+    iniset $OCTAVIA_CONF controller_worker amp_timezone $(readlink -e /etc/localtime | sed "s/\/usr\/share\/zoneinfo\///")
 
     iniuncomment $OCTAVIA_CONF health_manager heartbeat_key
     iniset $OCTAVIA_CONF health_manager heartbeat_key ${OCTAVIA_HEALTH_KEY}
@@ -339,7 +336,7 @@ function octavia_configure {
     iniset $OCTAVIA_CONF house_keeping amphora_expiry_age ${OCTAVIA_AMP_EXPIRY_AGE}
     iniset $OCTAVIA_CONF house_keeping load_balancer_expiry_age ${OCTAVIA_LB_EXPIRY_AGE}
 
-    iniset $OCTAVIA_CONF DEFAULT transport_url $(get_transport_url)
+    iniset_rpc_backend octavia $OCTAVIA_CONF
 
     iniset $OCTAVIA_CONF oslo_messaging rpc_thread_pool_size 2
     iniset $OCTAVIA_CONF oslo_messaging topic octavia_prov
