@@ -56,7 +56,6 @@ class BaseOS(object):
     def write_interface_file(self, interface, ip_address, prefixlen):
         interface = interface_file.InterfaceFile(
             name=interface,
-            if_type=consts.LO,
             addresses=[{
                 "address": ip_address,
                 "prefixlen": prefixlen
@@ -64,19 +63,13 @@ class BaseOS(object):
         )
         interface.write()
 
-    def write_vip_interface_file(self, interface, vip, ip_version,
-                                 prefixlen, gateway,
-                                 mtu, vrrp_ip,
-                                 host_routes, fixed_ips=None):
+    def write_vip_interface_file(self, interface, vips, mtu, vrrp_info,
+                                 fixed_ips=None):
         vip_interface = interface_file.VIPInterfaceFile(
             name=interface,
             mtu=mtu,
-            vip=vip,
-            ip_version=ip_version,
-            prefixlen=prefixlen,
-            gateway=gateway,
-            vrrp_ip=vrrp_ip,
-            host_routes=host_routes,
+            vips=vips,
+            vrrp_info=vrrp_info,
             fixed_ips=fixed_ips,
             topology=CONF.controller_worker.loadbalancer_topology)
         vip_interface.write()
@@ -102,16 +95,16 @@ class BaseOS(object):
             LOG.error('Failed to set up %s due to error: %s %s', interface,
                       e, e.output)
             raise exceptions.HTTPException(
-                response=webob.Response(json=dict(
-                    message='Error plugging {0}'.format(name),
-                    details=e.output), status=500))
+                response=webob.Response(json={
+                    'message': 'Error plugging {0}'.format(name),
+                    'details': e.output}, status=500))
 
 
 class Ubuntu(BaseOS):
 
     @classmethod
     def is_os_name(cls, os_name):
-        return os_name in ['ubuntu']
+        return os_name in ['ubuntu', 'debian']
 
     def cmd_get_version_of_installed_package(self, package_name):
         name = self._map_package_name(package_name)
