@@ -14,7 +14,6 @@
 # under the License.
 
 import ipaddress
-import itertools
 import os
 import socket
 import stat
@@ -25,7 +24,6 @@ import pyroute2
 import webob
 from werkzeug import exceptions
 
-from octavia.amphorae.backends.agent.api_server import util
 from octavia.common import constants as consts
 
 
@@ -90,7 +88,7 @@ class Plug(object):
             rendered_vips = self.render_vips(vips)
         except ValueError as e:
             vip_error_message = "Invalid VIP: {}".format(e)
-            return webob.Response(json=dict(message=vip_error_message),
+            return webob.Response(json={'message': vip_error_message},
                                   status=400)
 
         try:
@@ -98,7 +96,7 @@ class Plug(object):
                                              gateway, host_routes)
         except ValueError as e:
             return webob.Response(
-                json=dict(message="Invalid VRRP Address: {}".format(e)),
+                json={'message': "Invalid VRRP Address: {}".format(e)},
                 status=400)
 
         # Check if the interface is already in the network namespace
@@ -106,7 +104,7 @@ class Plug(object):
         # network namespace
         if self._netns_interface_exists(mac_address):
             return webob.Response(
-                json=dict(message="Interface already exists"), status=409)
+                json={'message': "Interface already exists"}, status=409)
 
         # Check that the interface has been fully plugged
         self._interface_by_mac(mac_address)
@@ -138,9 +136,9 @@ class Plug(object):
             vips=", ".join(v['ip_address'] for v in rendered_vips)
         )
 
-        return webob.Response(json=dict(
-            message="OK",
-            details=vip_message), status=202)
+        return webob.Response(json={
+            'message': "OK",
+            'details': vip_message}, status=202)
 
     def _check_ip_addresses(self, fixed_ips):
         if fixed_ips:
@@ -155,8 +153,8 @@ class Plug(object):
         try:
             self._check_ip_addresses(fixed_ips=fixed_ips)
         except socket.error:
-            return webob.Response(json=dict(
-                message="Invalid network port"), status=400)
+            return webob.Response(json={
+                'message': "Invalid network port"}, status=400)
 
         # Check if the interface is already in the network namespace
         # Do not attempt to re-plug the network if it is already in the
@@ -198,13 +196,12 @@ class Plug(object):
                     fixed_ips=fixed_ips,
                     mtu=mtu)
                 self._osutils.bring_interface_up(existing_interface, 'network')
-            util.send_member_advertisements(fixed_ips)
-            return webob.Response(json=dict(
-                message="OK",
-                details="Updated existing interface {interface}".format(
+            return webob.Response(json={
+                'message': "OK",
+                'details': "Updated existing interface {interface}".format(
                     # TODO(rm_work): Everything in this should probably use
                     # HTTP code 200, but continuing to use 202 for consistency.
-                    interface=existing_interface)), status=202)
+                    interface=existing_interface)}, status=202)
 
         # This is the interface as it was initially plugged into the
         # default network namespace, this will likely always be eth1
@@ -212,7 +209,13 @@ class Plug(object):
 
         # We need to determine the interface name when inside the namespace
         # to avoid name conflicts
-        netns_interface = self._netns_get_next_interface()
+        with pyroute2.NetNS(consts.AMPHORA_NAMESPACE,
+                            flags=os.O_CREAT) as netns:
+
+            # 1 means just loopback, but we should already have a VIP. This
+            # works for the add/delete/add case as we don't delete interfaces
+            # Note, eth0 is skipped because that is the VIP interface
+            netns_interface = 'eth{0}'.format(len(netns.get_links()))
 
         LOG.info('Plugged interface %s will become %s in the namespace %s',
                  default_netns_interface, netns_interface,
@@ -233,12 +236,11 @@ class Plug(object):
                      IFLA_IFNAME=netns_interface)
 
         self._osutils.bring_interface_up(netns_interface, 'network')
-        util.send_member_advertisements(fixed_ips)
 
-        return webob.Response(json=dict(
-            message="OK",
-            details="Plugged on interface {interface}".format(
-                interface=netns_interface)), status=202)
+        return webob.Response(json={
+            'message': "OK",
+            'details': "Plugged on interface {interface}".format(
+                interface=netns_interface)}, status=202)
 
     def _interface_by_mac(self, mac):
         try:
@@ -261,8 +263,8 @@ class Plug(object):
             with os.fdopen(os.open(filename, flags), 'w') as rescan_file:
                 rescan_file.write('1')
         raise exceptions.HTTPException(
-            response=webob.Response(json=dict(
-                details="No suitable network interface found"), status=404))
+            response=webob.Response(json={
+                'details': "No suitable network interface found"}, status=404))
 
     def _update_plugged_interfaces_file(self, interface, mac_address):
         # write interfaces to plugged_interfaces file and prevent duplicates
@@ -287,16 +289,3 @@ class Plug(object):
 
     def _netns_interface_exists(self, mac_address):
         return self._netns_interface_by_mac(mac_address) is not None
-
-    def _netns_get_next_interface(self):
-        with pyroute2.NetNS(consts.AMPHORA_NAMESPACE,
-                            flags=os.O_CREAT) as netns:
-            existing_ifaces = [
-                dict(link['attrs']).get(consts.IFLA_IFNAME)
-                for link in netns.get_links()]
-            # find the first unused ethXXX
-            for idx in itertools.count(start=2):
-                iface_name = f"eth{idx}"
-                if iface_name not in existing_ifaces:
-                    break
-            return iface_name
