@@ -135,7 +135,7 @@ class ListenersController(base.BaseController):
                 constants.LISTENER_PROTOCOLS_SUPPORTING_HEADER_INSERTION):
             raise exceptions.InvalidOption(
                 value='insert-headers',
-                option=('a %s protocol listener.' % listener_protocol))
+                option='a %s protocol listener.' % listener_protocol)
         if list(set(insert_header_list) - (
                 set(constants.SUPPORTED_HTTP_HEADERS +
                     constants.SUPPORTED_SSL_HEADERS))):
@@ -154,7 +154,7 @@ class ListenersController(base.BaseController):
                         headers.append(header_name)
                 raise exceptions.InvalidOption(
                     value=headers,
-                    option=('%s protocol listener.' % listener_protocol))
+                    option='%s protocol listener.' % listener_protocol)
 
     def _validate_cidr_compatible_with_vip(self, vip, allowed_cidrs):
         for cidr in allowed_cidrs:
