@@ -331,7 +331,7 @@ health_manager_opts = [
 ]
 
 oslo_messaging_opts = [
-    cfg.StrOpt('topic'),
+    cfg.StrOpt('topic', help=_('Topic (i.e. Queue) Name')),
 ]
 
 haproxy_amphora_opts = [
@@ -523,6 +523,10 @@ controller_worker_opts = [
                       'SINGLE - One amphora per load balancer. '
                       'ACTIVE_STANDBY - Two amphora per load balancer.')),
     cfg.BoolOpt('user_data_config_drive', default=False,
+                deprecated_for_removal=True,
+                deprecated_reason=_('User_data nova option is not used and is '
+                                    ' too small to replace the config_drive.'),
+                deprecated_since='Antelope(2023.1)',
                 help=_('If True, build cloud-init user-data that is passed '
                        'to the config drive on Amphora boot instead of '
                        'personality files. If False, utilize personality '
@@ -531,18 +535,10 @@ controller_worker_opts = [
                help=_('Number of times an amphora delete should be retried.')),
     cfg.IntOpt('amphora_delete_retry_interval', default=5,
                help=_('Time, in seconds, between amphora delete retries.')),
-    cfg.BoolOpt('event_notifications', default=True),
-    # 2000 attempts is around 2h45 with the default settings
-    cfg.IntOpt('db_commit_retry_attempts', default=2000,
-               help=_('The number of times the database action will be '
-                      'attempted.')),
-    cfg.IntOpt('db_commit_retry_initial_delay', default=1,
-               help=_('The initial delay before a retry attempt.')),
-    cfg.IntOpt('db_commit_retry_backoff', default=1,
-               help=_('The time to backoff retry attempts.')),
-    cfg.IntOpt('db_commit_retry_max', default=5,
-               help=_('The maximum amount of time to wait between retry '
-                      'attempts.')),
+    cfg.BoolOpt('event_notifications', default=True,
+                help=_('Enable octavia event notifications. See '
+                       'oslo_messaging_notifications section for additional '
+                       'requirements.'))
 ]
 
 task_flow_opts = [
