@@ -55,10 +55,16 @@ class CalculateAmphoraDelta(BaseNetworkTask):
 
     default_provides = constants.DELTA
 
+    # TODO(gthiemonge) ensure we no longer need vrrp_port
     def execute(self, loadbalancer, amphora, availability_zone):
         LOG.debug("Calculating network delta for amphora id: %s",
                   amphora.get(constants.ID))
 
+        vip_subnet_to_net_map = {
+            loadbalancer[constants.VIP_SUBNET_ID]:
+            loadbalancer[constants.VIP_NETWORK_ID]
+        }
+
         # Figure out what networks we want
         # seed with lb network(s)
         if (availability_zone and
@@ -71,10 +77,12 @@ class CalculateAmphoraDelta(BaseNetworkTask):
         db_lb = self.loadbalancer_repo.get(
             db_apis.get_session(), id=loadbalancer[constants.LOADBALANCER_ID])
 
-        desired_subnet_to_net_map = {
-            loadbalancer[constants.VIP_SUBNET_ID]:
-            loadbalancer[constants.VIP_NETWORK_ID]
-        }
+        desired_subnet_to_net_map = {}
+        for mgmt_net_id in management_nets:
+            for subnet_id in self.network_driver.get_network(
+                    mgmt_net_id).subnets:
+                desired_subnet_to_net_map[subnet_id] = mgmt_net_id
+        desired_subnet_to_net_map.update(vip_subnet_to_net_map)
 
         for pool in db_lb.pools:
             for member in pool.members:
@@ -93,12 +101,7 @@ class CalculateAmphoraDelta(BaseNetworkTask):
         nics = self.network_driver.get_plugged_networks(
             amphora[constants.COMPUTE_ID])
         # we don't have two nics in the same network
-        # Don't include the nics connected to the management network, we don't
-        # want to update these interfaces.
-        network_to_nic_map = {
-            nic.network_id: nic
-            for nic in nics
-            if nic.network_id not in management_nets}
+        network_to_nic_map = {nic.network_id: nic for nic in nics}
 
         plugged_network_ids = set(network_to_nic_map)
 
@@ -620,14 +623,20 @@ class AllocateVIP(BaseNetworkTask):
                   loadbalancer[constants.LOADBALANCER_ID])
         db_lb = self.loadbalancer_repo.get(
             db_apis.get_session(), id=loadbalancer[constants.LOADBALANCER_ID])
-        vip = self.network_driver.allocate_vip(db_lb)
+        vip, additional_vips = self.network_driver.allocate_vip(db_lb)
         LOG.info("Allocated vip with port id %s, subnet id %s, ip address %s "
                  "for load balancer %s",
                  loadbalancer[constants.VIP_PORT_ID],
                  loadbalancer[constants.VIP_SUBNET_ID],
                  loadbalancer[constants.VIP_ADDRESS],
                  loadbalancer[constants.LOADBALANCER_ID])
-        return vip.to_dict()
+        for add_vip in additional_vips:
+            LOG.debug('Allocated an additional VIP: subnet=%(subnet)s '
+                      'ip_address=%(ip)s', {'subnet': add_vip.subnet_id,
+                                            'ip': add_vip.ip_address})
+        return (vip.to_dict(),
+                [additional_vip.to_dict()
+                 for additional_vip in additional_vips])
 
     def revert(self, result, loadbalancer, *args, **kwargs):
         """Handle a failure to allocate vip."""
@@ -635,7 +644,8 @@ class AllocateVIP(BaseNetworkTask):
         if isinstance(result, failure.Failure):
             LOG.exception("Unable to allocate VIP")
             return
-        vip = data_models.Vip(**result)
+        vip, additional_vips = result
+        vip = data_models.Vip(**vip)
         LOG.warning("Deallocating vip %s", vip.ip_address)
         try:
             self.network_driver.deallocate_vip(vip)
@@ -654,7 +664,8 @@ class AllocateVIPforFailover(AllocateVIP):
         if isinstance(result, failure.Failure):
             LOG.exception("Unable to allocate VIP")
             return
-        vip = data_models.Vip(**result)
+        vip, additional_vips = result
+        vip = data_models.Vip(**vip)
         LOG.info("Failover revert is not deallocating vip %s because this is "
                  "a failover.", vip.ip_address)
 
@@ -969,22 +980,26 @@ class CreateVIPBasePort(BaseNetworkTask):
                         multiplier=CONF.networking.retry_backoff,
                         min=CONF.networking.retry_interval,
                         max=CONF.networking.retry_max), reraise=True)
-    def execute(self, vip, vip_sg_id, amphora_id):
+    def execute(self, vip, vip_sg_id, amphora_id, additional_vips):
         port_name = constants.AMP_BASE_PORT_PREFIX + amphora_id
         fixed_ips = [{constants.SUBNET_ID: vip[constants.SUBNET_ID]}]
         sg_id = []
         if vip_sg_id:
             sg_id = [vip_sg_id]
+        secondary_ips = [vip[constants.IP_ADDRESS]]
+        for add_vip in additional_vips:
+            secondary_ips.append(add_vip[constants.IP_ADDRESS])
         port = self.network_driver.create_port(
             vip[constants.NETWORK_ID], name=port_name, fixed_ips=fixed_ips,
-            secondary_ips=[vip[constants.IP_ADDRESS]],
+            secondary_ips=secondary_ips,
             security_group_ids=sg_id,
             qos_policy_id=vip[constants.QOS_POLICY_ID])
         LOG.info('Created port %s with ID %s for amphora %s',
                  port_name, port.id, amphora_id)
         return port.to_dict(recurse=True)
 
-    def revert(self, result, vip, vip_sg_id, amphora_id, *args, **kwargs):
+    def revert(self, result, vip, vip_sg_id, amphora_id, additional_vips,
+               *args, **kwargs):
         if isinstance(result, failure.Failure):
             return
         try:
