@@ -19,18 +19,21 @@ reference
 """
 
 import datetime
+from typing import Optional
 
 from oslo_config import cfg
 from oslo_db import api as oslo_db_api
 from oslo_db import exception as db_exception
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
-from oslo_utils import excutils
 from oslo_utils import uuidutils
 from sqlalchemy.orm import noload
+from sqlalchemy.orm import Session
 from sqlalchemy.orm import subqueryload
+from sqlalchemy import select
 from sqlalchemy.sql.expression import false
 from sqlalchemy.sql import func
+from sqlalchemy import update
 
 from octavia.common import constants as consts
 from octavia.common import data_models
@@ -210,6 +213,7 @@ class Repositories(object):
     def __init__(self):
         self.load_balancer = LoadBalancerRepository()
         self.vip = VipRepository()
+        self.additional_vip = AdditionalVipRepository()
         self.health_monitor = HealthMonitorRepository()
         self.session_persistence = SessionPersistenceRepository()
         self.pool = PoolRepository()
@@ -231,7 +235,8 @@ class Repositories(object):
         self.availability_zone = AvailabilityZoneRepository()
         self.availability_zone_profile = AvailabilityZoneProfileRepository()
 
-    def create_load_balancer_and_vip(self, session, lb_dict, vip_dict):
+    def create_load_balancer_and_vip(self, session, lb_dict, vip_dict,
+                                     additional_vip_dicts=None):
         """Inserts load balancer and vip entities into the database.
 
         Inserts load balancer and vip entities into the database in one
@@ -240,8 +245,10 @@ class Repositories(object):
         :param session: A Sql Alchemy database session.
         :param lb_dict: Dictionary representation of a load balancer
         :param vip_dict: Dictionary representation of a vip
+        :param additional_vip_dicts: Dict representations of additional vips
         :returns: octavia.common.data_models.LoadBalancer
         """
+        additional_vip_dicts = additional_vip_dicts or []
         with session.begin(subtransactions=True):
             if not lb_dict.get('id'):
                 lb_dict['id'] = uuidutils.generate_uuid()
@@ -250,6 +257,13 @@ class Repositories(object):
             vip_dict['load_balancer_id'] = lb_dict['id']
             vip = models.Vip(**vip_dict)
             session.add(vip)
+            for add_vip_dict in additional_vip_dicts:
+                add_vip_dict['load_balancer_id'] = lb_dict['id']
+                add_vip_dict['network_id'] = vip_dict.get('network_id')
+                add_vip_dict['port_id'] = vip_dict.get('port_id')
+                add_vip = models.AdditionalVip(**add_vip_dict)
+                session.add(add_vip)
+
         return self.load_balancer.get(session, id=lb.id)
 
     def create_pool_on_load_balancer(self, session, pool_dict,
@@ -392,11 +406,8 @@ class Repositories(object):
         # Note: You cannot just use the current count as the in-use
         # value as we don't want to lock the whole resource table
         try:
-            quotas = (lock_session.query(models.Quotas)
-                      .filter_by(project_id=project_id)
-                      .populate_existing()
-                      .with_for_update()
-                      .first())
+            quotas = lock_session.query(models.Quotas).filter_by(
+                project_id=project_id).with_for_update().first()
             if _class == data_models.LoadBalancer:
                 # Decide which quota to use
                 if quotas.load_balancer is None:
@@ -564,11 +575,8 @@ class Repositories(object):
 
         # Lock the project record in the database to block other quota checks
         try:
-            quotas = (lock_session.query(models.Quotas)
-                      .filter_by(project_id=project_id)
-                      .populate_existing()
-                      .with_for_update()
-                      .first())
+            quotas = lock_session.query(models.Quotas).filter_by(
+                project_id=project_id).with_for_update().first()
             if not quotas:
                 if not CONF.api_settings.auth_strategy == consts.NOAUTH:
                     LOG.error('Quota decrement on %(clss)s called on '
@@ -658,153 +666,6 @@ class Repositories(object):
                         {'proj': project_id})
             raise exceptions.ProjectBusyException() from e
 
-    def create_load_balancer_tree(self, session, lock_session, lb_dict):
-        listener_dicts = lb_dict.pop('listeners', [])
-        vip_dict = lb_dict.pop('vip')
-        try:
-            if self.check_quota_met(session,
-                                    lock_session,
-                                    data_models.LoadBalancer,
-                                    lb_dict['project_id']):
-                raise exceptions.QuotaException(
-                    resource=data_models.LoadBalancer._name())
-            lb_dm = self.create_load_balancer_and_vip(
-                lock_session, lb_dict, vip_dict)
-            for listener_dict in listener_dicts:
-                # Add listener quota check
-                if self.check_quota_met(session,
-                                        lock_session,
-                                        data_models.Listener,
-                                        lb_dict['project_id']):
-                    raise exceptions.QuotaException(
-                        resource=data_models.Listener._name())
-                pool_dict = listener_dict.pop('default_pool', None)
-                l7policies_dict = listener_dict.pop('l7policies', None)
-                sni_containers = listener_dict.pop('sni_containers', [])
-                if pool_dict:
-                    # Add pool quota check
-                    if self.check_quota_met(session,
-                                            lock_session,
-                                            data_models.Pool,
-                                            lb_dict['project_id']):
-                        raise exceptions.QuotaException(
-                            resource=data_models.Pool._name())
-                    hm_dict = pool_dict.pop('health_monitor', None)
-                    member_dicts = pool_dict.pop('members', [])
-                    sp_dict = pool_dict.pop('session_persistence', None)
-                    pool_dict['load_balancer_id'] = lb_dm.id
-                    del pool_dict['listener_id']
-                    pool_dm = self.pool.create(lock_session, **pool_dict)
-                    if sp_dict:
-                        sp_dict['pool_id'] = pool_dm.id
-                        self.session_persistence.create(lock_session,
-                                                        **sp_dict)
-                    if hm_dict:
-                        # Add hm quota check
-                        if self.check_quota_met(session,
-                                                lock_session,
-                                                data_models.HealthMonitor,
-                                                lb_dict['project_id']):
-                            raise exceptions.QuotaException(
-                                resource=data_models.HealthMonitor._name())
-                        hm_dict['id'] = pool_dm.id
-                        hm_dict['pool_id'] = pool_dm.id
-                        self.health_monitor.create(lock_session, **hm_dict)
-                    for r_member_dict in member_dicts:
-                        # Add member quota check
-                        if self.check_quota_met(session,
-                                                lock_session,
-                                                data_models.Member,
-                                                lb_dict['project_id']):
-                            raise exceptions.QuotaException(
-                                resource=data_models.Member._name())
-                        r_member_dict['pool_id'] = pool_dm.id
-                        self.member.create(lock_session, **r_member_dict)
-                    listener_dict['default_pool_id'] = pool_dm.id
-                self.listener.create(lock_session, **listener_dict)
-                for sni_container in sni_containers:
-                    self.sni.create(lock_session, **sni_container)
-                if l7policies_dict:
-                    for policy_dict in l7policies_dict:
-                        # Add l7policy quota check
-                        if self.check_quota_met(session,
-                                                lock_session,
-                                                data_models.L7Policy,
-                                                lb_dict['project_id']):
-                            raise exceptions.QuotaException(
-                                resource=data_models.L7Policy._name())
-                        l7rules_dict = policy_dict.pop('l7rules')
-                        if policy_dict.get('redirect_pool'):
-                            # Add pool quota check
-                            if self.check_quota_met(session,
-                                                    lock_session,
-                                                    data_models.Pool,
-                                                    lb_dict['project_id']):
-                                raise exceptions.QuotaException(
-                                    resource=data_models.Pool._name())
-                            r_pool_dict = policy_dict.pop(
-                                'redirect_pool')
-                            r_hm_dict = r_pool_dict.pop('health_monitor',
-                                                        None)
-                            r_sp_dict = r_pool_dict.pop(
-                                'session_persistence', None)
-                            r_member_dicts = r_pool_dict.pop('members', [])
-                            if 'listener_id' in r_pool_dict.keys():
-                                del r_pool_dict['listener_id']
-                            r_pool_dm = self.pool.create(lock_session,
-                                                         **r_pool_dict)
-                            if r_sp_dict:
-                                r_sp_dict['pool_id'] = r_pool_dm.id
-                                self.session_persistence.create(lock_session,
-                                                                **r_sp_dict)
-                            if r_hm_dict:
-                                # Add hm quota check
-                                if self.check_quota_met(
-                                        session,
-                                        lock_session,
-                                        data_models.HealthMonitor,
-                                        lb_dict['project_id']):
-                                    res = data_models.HealthMonitor
-                                    raise exceptions.QuotaException(
-                                        resource=res._name())
-                                r_hm_dict['id'] = r_pool_dm.id
-                                r_hm_dict['pool_id'] = r_pool_dm.id
-                                self.health_monitor.create(lock_session,
-                                                           **r_hm_dict)
-                            for r_member_dict in r_member_dicts:
-                                # Add member quota check
-                                if self.check_quota_met(
-                                        session,
-                                        lock_session,
-                                        data_models.Member,
-                                        lb_dict['project_id']):
-                                    raise exceptions.QuotaException(
-                                        resource=data_models.Member._name())
-                                r_member_dict['pool_id'] = r_pool_dm.id
-                                self.member.create(lock_session,
-                                                   **r_member_dict)
-                            policy_dict['redirect_pool_id'] = r_pool_dm.id
-                        policy_dm = self.l7policy.create(lock_session,
-                                                         **policy_dict)
-                        for rule_dict in l7rules_dict:
-                            # Add l7rule quota check
-                            if self.check_quota_met(
-                                    session,
-                                    lock_session,
-                                    data_models.L7Rule,
-                                    lb_dict['project_id']):
-                                raise exceptions.QuotaException(
-                                    resource=data_models.L7Rule._name())
-                            rule_dict['l7policy_id'] = policy_dm.id
-                            self.l7rule.create(lock_session, **rule_dict)
-            lock_session.commit()
-        except Exception:
-            with excutils.save_and_reraise_exception():
-                lock_session.rollback()
-
-        session.expire_all()
-        return self.load_balancer.get(session, id=lb_dm.id)
-
     def get_amphora_stats(self, session, amp_id):
         """Gets the statistics for all listeners on an amphora.
 
@@ -854,6 +715,7 @@ class LoadBalancerRepository(BaseRepository):
         # no-load (blank) the tables we don't need
         query_options = (
             subqueryload(models.LoadBalancer.vip),
+            subqueryload(models.LoadBalancer.additional_vips),
             subqueryload(models.LoadBalancer.amphorae),
             subqueryload(models.LoadBalancer.pools),
             subqueryload(models.LoadBalancer.listeners),
@@ -880,10 +742,8 @@ class LoadBalancerRepository(BaseRepository):
         :returns: bool
         """
         with session.begin(subtransactions=True):
-            lb = (session.query(self.model_class)
-                  .populate_existing()
-                  .with_for_update()
-                  .filter_by(id=id).one())
+            lb = session.query(self.model_class).with_for_update().filter_by(
+                id=id).one()
             is_delete = status == consts.PENDING_DELETE
             acceptable_statuses = (
                 consts.DELETABLE_STATUSES
@@ -914,10 +774,8 @@ class LoadBalancerRepository(BaseRepository):
         :returns: bool
         """
         with session.begin(subtransactions=True):
-            lb = (session.query(self.model_class)
-                  .populate_existing()
-                  .with_for_update()
-                  .filter_by(id=id).one())
+            lb = session.query(self.model_class).with_for_update().filter_by(
+                id=id).one()
             if lb.provisioning_status not in consts.FAILOVERABLE_STATUSES:
                 if raise_exception:
                     raise exceptions.ImmutableObject(
@@ -938,6 +796,21 @@ class VipRepository(BaseRepository):
                 load_balancer_id=load_balancer_id).update(model_kwargs)
 
 
+class AdditionalVipRepository(BaseRepository):
+    model_class = models.AdditionalVip
+
+    def update(self, session, load_balancer_id, subnet_id,
+               **model_kwargs):
+        """Updates an additional vip entity in the database.
+
+        Uses load_balancer_id + subnet_id.
+        """
+        with session.begin(subtransactions=True):
+            session.query(self.model_class).filter_by(
+                load_balancer_id=load_balancer_id,
+                subnet_id=subnet_id).update(model_kwargs)
+
+
 class HealthMonitorRepository(BaseRepository):
     model_class = models.HealthMonitor
 
@@ -1270,13 +1143,10 @@ class ListenerStatisticsRepository(BaseRepository):
                 listener_id=delta_stats.listener_id,
                 amphora_id=delta_stats.amphora_id).count()
             if count:
-                existing_stats = (
-                    session.query(self.model_class)
-                    .populate_existing()
-                    .with_for_update()
-                    .filter_by(
-                        listener_id=delta_stats.listener_id,
-                        amphora_id=delta_stats.amphora_id).one())
+                existing_stats = session.query(
+                    self.model_class).with_for_update().filter_by(
+                    listener_id=delta_stats.listener_id,
+                    amphora_id=delta_stats.amphora_id).one()
                 existing_stats += delta_stats
                 existing_stats.active_connections = (
                     delta_stats.active_connections)
@@ -1359,10 +1229,8 @@ class AmphoraRepository(BaseRepository):
             filters['cached_zone'] = availability_zone
 
         with session.begin(subtransactions=True):
-            amp = (session.query(self.model_class)
-                   .populate_existing()
-                   .with_for_update()
-                   .filter_by(**filters).first())
+            amp = session.query(self.model_class).with_for_update().filter_by(
+                **filters).first()
 
             if amp is None:
                 return None
@@ -1413,15 +1281,12 @@ class AmphoraRepository(BaseRepository):
             seconds=expired_seconds)
 
         with session.begin(subtransactions=True):
-            amp = (session.query(self.model_class)
-                   .populate_existing()
-                   .with_for_update()
-                   .filter(
-                       self.model_class.status.notin_(
-                           [consts.DELETED, consts.PENDING_DELETE]),
-                       self.model_class.cert_busy == false(),
-                       self.model_class.cert_expiration < expired_date)
-                   .first())
+            amp = session.query(self.model_class).with_for_update().filter(
+                self.model_class.status.notin_(
+                    [consts.DELETED, consts.PENDING_DELETE]),
+                self.model_class.cert_busy == false(),
+                self.model_class.cert_expiration < expired_date
+            ).first()
 
             if amp is None:
                 return None
@@ -1520,11 +1385,8 @@ class AmphoraRepository(BaseRepository):
         :raises NoResultFound: The amphora was not found or already deleted.
         :returns: None
         """
-        amp = (lock_session.query(self.model_class)
-               .populate_existing()
-               .with_for_update()
-               .filter_by(id=id)
-               .filter(self.model_class.status != consts.DELETED).one())
+        amp = lock_session.query(self.model_class).with_for_update().filter_by(
+            id=id).filter(self.model_class.status != consts.DELETED).one()
         if amp.status not in [consts.AMPHORA_READY, consts.ERROR]:
             raise exceptions.ImmutableObject(resource=consts.AMPHORA, id=id)
         amp.status = consts.PENDING_DELETE
@@ -1671,35 +1533,99 @@ class AmphoraHealthRepository(BaseRepository):
         # In this case, the amphora is expired.
         return amphora_model is None
 
-    def get_stale_amphora(self, session):
+    def get_stale_amphora(self,
+                          lock_session: Session) -> Optional[models.Amphora]:
         """Retrieves a stale amphora from the health manager database.
 
-        :param session: A Sql Alchemy database session.
+        :param lock_session: A Sql Alchemy database autocommit session.
         :returns: [octavia.common.data_model]
         """
-
         timeout = CONF.health_manager.heartbeat_timeout
         expired_time = datetime.datetime.utcnow() - datetime.timedelta(
             seconds=timeout)
 
-        amp = session.query(
-            self.model_class
-        ).populate_existing(
-        ).with_for_update(
-        ).filter_by(
-            busy=False
-        ).filter(
-            self.model_class.last_update < expired_time
-        ).order_by(
-            func.random()
-        ).first()
+        # Update any amphora that were previously FAILOVER_STOPPED
+        # but are no longer expired.
+        self.update_failover_stopped(lock_session, expired_time)
 
-        if amp is None:
+        # Handle expired amphora
+        expired_ids_query = select(self.model_class.amphora_id).where(
+            self.model_class.busy == false()).where(
+                self.model_class.last_update < expired_time)
+
+        expired_count = lock_session.scalar(
+            select(func.count()).select_from(expired_ids_query))
+
+        threshold = CONF.health_manager.failover_threshold
+        if threshold is not None and expired_count >= threshold:
+            LOG.error('Stale amphora count reached the threshold '
+                      '(%(th)s). %(count)s amphorae were set into '
+                      'FAILOVER_STOPPED status.',
+                      {'th': threshold, 'count': expired_count})
+            lock_session.execute(
+                update(
+                    models.Amphora
+                ).where(
+                    models.Amphora.status.notin_(
+                        [consts.DELETED, consts.PENDING_DELETE])
+                ).where(
+                    models.Amphora.id.in_(expired_ids_query)
+                ).values(
+                    status=consts.AMPHORA_FAILOVER_STOPPED
+                ).execution_options(synchronize_session="fetch"))
             return None
 
-        amp.busy = True
+        # We don't want to attempt to failover amphora that are not
+        # currently in the ALLOCATED or FAILOVER_STOPPED state.
+        # i.e. Not DELETED, PENDING_*, etc.
+        allocated_amp_ids_subquery = (
+            select(models.Amphora.id).where(
+                models.Amphora.status.in_(
+                    [consts.AMPHORA_ALLOCATED,
+                     consts.AMPHORA_FAILOVER_STOPPED])))
 
-        return amp.to_data_model()
+        # Pick one expired amphora for automatic failover
+        amp_health = lock_session.query(
+            self.model_class
+        ).with_for_update(
+        ).filter(
+            self.model_class.amphora_id.in_(expired_ids_query)
+        ).filter(
+            self.model_class.amphora_id.in_(allocated_amp_ids_subquery)
+        ).order_by(
+            func.random()
+        ).limit(1).first()
+
+        if amp_health is None:
+            return None
+
+        amp_health.busy = True
+
+        return amp_health.to_data_model()
+
+    def update_failover_stopped(self, lock_session: Session,
+                                expired_time: datetime) -> None:
+        """Updates the status of amps that are FAILOVER_STOPPED."""
+        # Update any FAILOVER_STOPPED amphora that are no longer stale
+        # back to ALLOCATED.
+        # Note: This uses sqlalchemy 2.0 syntax
+        not_expired_ids_subquery = (
+            select(self.model_class.amphora_id).where(
+                self.model_class.busy == false()
+            ).where(
+                self.model_class.last_update >= expired_time
+            ))
+
+        # Note: mysql and sqlite do not support RETURNING, so we cannot
+        #       get back the affected amphora IDs. (09/2022)
+        lock_session.execute(
+            update(models.Amphora).where(
+                models.Amphora.status == consts.AMPHORA_FAILOVER_STOPPED
+            ).where(
+                models.Amphora.id.in_(not_expired_ids_subquery)
+            ).values(
+                status=consts.AMPHORA_ALLOCATED
+            ).execution_options(synchronize_session="fetch"))
 
 
 class VRRPGroupRepository(BaseRepository):
@@ -1985,11 +1911,8 @@ class QuotasRepository(BaseRepository):
     def update(self, session, project_id, **model_kwargs):
         with session.begin(subtransactions=True):
             kwargs_quota = model_kwargs['quota']
-            quotas = (
-                session.query(self.model_class)
-                .filter_by(project_id=project_id)
-                .populate_existing()
-                .with_for_update().first())
+            quotas = session.query(self.model_class).filter_by(
+                project_id=project_id).with_for_update().first()
             if not quotas:
                 quotas = models.Quotas(project_id=project_id)
 
@@ -2001,11 +1924,8 @@ class QuotasRepository(BaseRepository):
 
     def delete(self, session, project_id):
         with session.begin(subtransactions=True):
-            quotas = (
-                session.query(self.model_class)
-                .filter_by(project_id=project_id)
-                .populate_existing()
-                .with_for_update().first())
+            quotas = session.query(self.model_class).filter_by(
+                project_id=project_id).with_for_update().first()
             if not quotas:
                 raise exceptions.NotFound(
                     resource=data_models.Quotas._name(), id=project_id)
