@@ -26,6 +26,10 @@ from octavia.controller.worker.v2.flows import load_balancer_flows
 import octavia.tests.unit.base as base
 
 
+class MockNOTIFIER(mock.MagicMock):
+    info = mock.MagicMock()
+
+
 # NOTE: We patch the get_network_driver for all the calls so we don't
 # inadvertently make real calls.
 @mock.patch('octavia.common.utils.get_network_driver')
@@ -40,7 +44,10 @@ class TestLoadBalancerFlows(base.TestCase):
         self.conf.config(group="nova", enable_anti_affinity=False)
         self.LBFlow = load_balancer_flows.LoadBalancerFlows()
 
-    def test_get_create_load_balancer_flow(self, mock_get_net_driver):
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
+    def test_get_create_load_balancer_flow(self, mock_get_net_driver,
+                                           mock_notifier):
         amp_flow = self.LBFlow.get_create_load_balancer_flow(
             constants.TOPOLOGY_SINGLE)
         self.assertIsInstance(amp_flow, flow.Flow)
@@ -50,8 +57,10 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertIn(constants.COMPUTE_ID, amp_flow.provides)
         self.assertIn(constants.COMPUTE_OBJ, amp_flow.provides)
 
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
     def test_get_create_active_standby_load_balancer_flow(
-            self, mock_get_net_driver):
+            self, mock_get_net_driver, mock_notifier):
         amp_flow = self.LBFlow.get_create_load_balancer_flow(
             constants.TOPOLOGY_ACTIVE_STANDBY)
         self.assertIsInstance(amp_flow, flow.Flow)
@@ -61,8 +70,10 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertIn(constants.COMPUTE_ID, amp_flow.provides)
         self.assertIn(constants.COMPUTE_OBJ, amp_flow.provides)
 
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
     def test_get_create_anti_affinity_active_standby_load_balancer_flow(
-            self, mock_get_net_driver):
+            self, mock_get_net_driver, mock_notifier):
         self.conf.config(group="nova", enable_anti_affinity=True)
 
         self._LBFlow = load_balancer_flows.LoadBalancerFlows()
@@ -77,13 +88,18 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertIn(constants.COMPUTE_OBJ, amp_flow.provides)
         self.conf.config(group="nova", enable_anti_affinity=False)
 
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
     def test_get_create_bogus_topology_load_balancer_flow(
-            self, mock_get_net_driver):
+            self, mock_get_net_driver, mock_notifier):
         self.assertRaises(exceptions.InvalidTopology,
                           self.LBFlow.get_create_load_balancer_flow,
                           'BOGUS')
 
-    def test_get_delete_load_balancer_flow(self, mock_get_net_driver):
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
+    def test_get_delete_load_balancer_flow(self, mock_get_net_driver,
+                                           mock_notifier):
         lb_mock = mock.Mock()
         listener_mock = mock.Mock()
         listener_mock.id = '123'
@@ -100,11 +116,14 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertEqual(0, len(lb_flow.provides))
         self.assertEqual(3, len(lb_flow.requires))
 
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
     @mock.patch('octavia.db.repositories.LoadBalancerRepository.get')
     @mock.patch('octavia.db.api.get_session', return_value=mock.MagicMock())
     def test_get_delete_load_balancer_flow_cascade(self, mock_session,
                                                    mock_get_lb,
-                                                   mock_get_net_driver):
+                                                   mock_get_net_driver,
+                                                   mock_notifier):
         lb_mock = mock.Mock()
         listener_mock = mock.Mock()
         listener_mock.id = '123'
@@ -141,7 +160,10 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertEqual(1, len(lb_flow.provides))
         self.assertEqual(4, len(lb_flow.requires))
 
-    def test_get_update_load_balancer_flow(self, mock_get_net_driver):
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
+    def test_get_update_load_balancer_flow(self, mock_get_net_driver,
+                                           mock_notifier):
 
         lb_flow = self.LBFlow.get_update_load_balancer_flow()
 
@@ -153,7 +175,10 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertEqual(0, len(lb_flow.provides))
         self.assertEqual(3, len(lb_flow.requires))
 
-    def test_get_post_lb_amp_association_flow(self, mock_get_net_driver):
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
+    def test_get_post_lb_amp_association_flow(self, mock_get_net_driver,
+                                              mock_notifier):
         amp_flow = self.LBFlow.get_post_lb_amp_association_flow(
             '123', constants.TOPOLOGY_SINGLE)
 
@@ -174,17 +199,16 @@ class TestLoadBalancerFlows(base.TestCase):
 
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
         self.assertIn(constants.UPDATE_DICT, amp_flow.requires)
-        self.assertIn(constants.AMPHORA_ID, amp_flow.requires)
 
         self.assertIn(constants.AMPHORAE, amp_flow.provides)
-        self.assertIn(constants.AMPHORAE_STATUS, amp_flow.provides)
         self.assertIn(constants.AMP_VRRP_INT, amp_flow.provides)
         self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, amp_flow.provides)
         self.assertIn(constants.LOADBALANCER, amp_flow.provides)
 
-        self.assertEqual(3, len(amp_flow.requires), amp_flow.requires)
-        self.assertEqual(5, len(amp_flow.provides), amp_flow.provides)
+        self.assertEqual(2, len(amp_flow.requires), amp_flow.requires)
+        self.assertEqual(4, len(amp_flow.provides), amp_flow.provides)
 
+        # Test mark_active=False
         amp_flow = self.LBFlow.get_post_lb_amp_association_flow(
             '123', constants.TOPOLOGY_ACTIVE_STANDBY)
 
@@ -192,19 +216,19 @@ class TestLoadBalancerFlows(base.TestCase):
 
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
         self.assertIn(constants.UPDATE_DICT, amp_flow.requires)
-        self.assertIn(constants.AMPHORA_ID, amp_flow.requires)
 
         self.assertIn(constants.AMPHORAE, amp_flow.provides)
-        self.assertIn(constants.AMPHORAE_STATUS, amp_flow.provides)
         self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, amp_flow.provides)
         self.assertIn(constants.AMP_VRRP_INT, amp_flow.provides)
         self.assertIn(constants.LOADBALANCER, amp_flow.provides)
 
-        self.assertEqual(3, len(amp_flow.requires), amp_flow.requires)
-        self.assertEqual(5, len(amp_flow.provides), amp_flow.provides)
+        self.assertEqual(2, len(amp_flow.requires), amp_flow.requires)
+        self.assertEqual(4, len(amp_flow.provides), amp_flow.provides)
 
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
     def test_get_create_load_balancer_flows_single_listeners(
-            self, mock_get_net_driver):
+            self, mock_get_net_driver, mock_notifier):
         create_flow = (
             self.LBFlow.get_create_load_balancer_flow(
                 constants.TOPOLOGY_SINGLE, True
@@ -231,13 +255,16 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertIn(constants.UPDATED_PORTS, create_flow.provides)
         self.assertIn(constants.SERVER_PEM, create_flow.provides)
         self.assertIn(constants.VIP, create_flow.provides)
+        self.assertIn(constants.ADDITIONAL_VIPS, create_flow.provides)
         self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, create_flow.provides)
 
         self.assertEqual(6, len(create_flow.requires))
-        self.assertEqual(14, len(create_flow.provides))
+        self.assertEqual(15, len(create_flow.provides))
 
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
     def test_get_create_load_balancer_flows_active_standby_listeners(
-            self, mock_get_net_driver):
+            self, mock_get_net_driver, mock_notifier):
         create_flow = (
             self.LBFlow.get_create_load_balancer_flow(
                 constants.TOPOLOGY_ACTIVE_STANDBY, True
@@ -259,7 +286,6 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertIn(constants.AMPHORA_ID, create_flow.provides)
         self.assertIn(constants.AMPHORA_NETWORK_CONFIG, create_flow.provides)
         self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, create_flow.provides)
-        self.assertIn(constants.AMPHORAE_STATUS, create_flow.provides)
         self.assertIn(constants.COMPUTE_ID, create_flow.provides)
         self.assertIn(constants.COMPUTE_OBJ, create_flow.provides)
         self.assertIn(constants.DELTAS, create_flow.provides)
@@ -268,6 +294,7 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertIn(constants.SERVER_PEM, create_flow.provides)
         self.assertIn(constants.SUBNET, create_flow.provides)
         self.assertIn(constants.VIP, create_flow.provides)
+        self.assertIn(constants.ADDITIONAL_VIPS, create_flow.provides)
 
         self.assertEqual(6, len(create_flow.requires), create_flow.requires)
         self.assertEqual(17, len(create_flow.provides),
@@ -300,17 +327,24 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertIn(constants.LOADBALANCER, failover_flow.provides)
         self.assertIn(constants.SERVER_PEM, failover_flow.provides)
         self.assertIn(constants.VIP, failover_flow.provides)
+        self.assertIn(constants.ADDITIONAL_VIPS, failover_flow.provides)
         self.assertIn(constants.VIP_SG_ID, failover_flow.provides)
 
         self.assertEqual(6, len(failover_flow.requires),
                          failover_flow.requires)
-        self.assertEqual(12, len(failover_flow.provides),
+        self.assertEqual(13, len(failover_flow.provides),
                          failover_flow.provides)
 
-    def test_get_failover_LB_flow_no_amps_single(self, mock_get_net_driver):
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
+    def test_get_failover_LB_flow_no_amps_single(self, mock_get_net_driver,
+                                                 mock_notifier):
         self._test_get_failover_LB_flow_single([])
 
-    def test_get_failover_LB_flow_one_amp_single(self, mock_get_net_driver):
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
+    def test_get_failover_LB_flow_one_amp_single(self, mock_get_net_driver,
+                                                 mock_notifier):
         amphora_dict = {constants.ID: uuidutils.generate_uuid(),
                         constants.ROLE: constants.ROLE_STANDALONE,
                         constants.COMPUTE_ID: uuidutils.generate_uuid(),
@@ -318,8 +352,11 @@ class TestLoadBalancerFlows(base.TestCase):
 
         self._test_get_failover_LB_flow_single([amphora_dict])
 
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
     def test_get_failover_LB_flow_one_bogus_amp_single(self,
-                                                       mock_get_net_driver):
+                                                       mock_get_net_driver,
+                                                       mock_notifier):
         amphora_dict = {constants.ID: uuidutils.generate_uuid(),
                         constants.ROLE: 'bogus',
                         constants.COMPUTE_ID: uuidutils.generate_uuid(),
@@ -327,7 +364,10 @@ class TestLoadBalancerFlows(base.TestCase):
 
         self._test_get_failover_LB_flow_single([amphora_dict])
 
-    def test_get_failover_LB_flow_two_amp_single(self, mock_get_net_driver):
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
+    def test_get_failover_LB_flow_two_amp_single(self, mock_get_net_driver,
+                                                 mock_notifier):
         amphora_dict = {constants.ID: uuidutils.generate_uuid()}
         amphora2_dict = {constants.ID: uuidutils.generate_uuid(),
                          constants.ROLE: constants.ROLE_STANDALONE,
@@ -363,17 +403,24 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertIn(constants.LOADBALANCER, failover_flow.provides)
         self.assertIn(constants.SERVER_PEM, failover_flow.provides)
         self.assertIn(constants.VIP, failover_flow.provides)
+        self.assertIn(constants.ADDITIONAL_VIPS, failover_flow.provides)
         self.assertIn(constants.VIP_SG_ID, failover_flow.provides)
 
         self.assertEqual(6, len(failover_flow.requires),
                          failover_flow.requires)
-        self.assertEqual(12, len(failover_flow.provides),
+        self.assertEqual(13, len(failover_flow.provides),
                          failover_flow.provides)
 
-    def test_get_failover_LB_flow_no_amps_act_stdby(self, mock_get_net_driver):
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
+    def test_get_failover_LB_flow_no_amps_act_stdby(self, mock_get_net_driver,
+                                                    mock_notifier):
         self._test_get_failover_LB_flow_no_amps_act_stdby([])
 
-    def test_get_failover_LB_flow_one_amps_act_stdby(self, amphorae):
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
+    def test_get_failover_LB_flow_one_amps_act_stdby(self, amphorae,
+                                                     mock_notifier):
         amphora_dict = {constants.ID: uuidutils.generate_uuid(),
                         constants.ROLE: constants.ROLE_MASTER,
                         constants.COMPUTE_ID: uuidutils.generate_uuid(),
@@ -381,8 +428,11 @@ class TestLoadBalancerFlows(base.TestCase):
 
         self._test_get_failover_LB_flow_no_amps_act_stdby([amphora_dict])
 
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
     def test_get_failover_LB_flow_two_amps_act_stdby(self,
-                                                     mock_get_net_driver):
+                                                     mock_get_net_driver,
+                                                     mock_notifier):
         amphora_dict = {constants.ID: uuidutils.generate_uuid(),
                         constants.ROLE: constants.ROLE_MASTER,
                         constants.COMPUTE_ID: uuidutils.generate_uuid(),
@@ -397,8 +447,11 @@ class TestLoadBalancerFlows(base.TestCase):
         self._test_get_failover_LB_flow_no_amps_act_stdby([amphora_dict,
                                                            amphora2_dict])
 
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
     def test_get_failover_LB_flow_three_amps_act_stdby(self,
-                                                       mock_get_net_driver):
+                                                       mock_get_net_driver,
+                                                       mock_notifier):
         amphora_dict = {constants.ID: uuidutils.generate_uuid(),
                         constants.ROLE: constants.ROLE_MASTER,
                         constants.COMPUTE_ID: uuidutils.generate_uuid(),
@@ -417,8 +470,10 @@ class TestLoadBalancerFlows(base.TestCase):
         self._test_get_failover_LB_flow_no_amps_act_stdby(
             [amphora_dict, amphora2_dict, amphora3_dict])
 
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
     def test_get_failover_LB_flow_two_amps_bogus_act_stdby(
-            self, mock_get_net_driver):
+            self, mock_get_net_driver, mock_notifier):
         amphora_dict = {constants.ID: uuidutils.generate_uuid(),
                         constants.ROLE: 'bogus',
                         constants.COMPUTE_ID: uuidutils.generate_uuid(),
@@ -433,8 +488,10 @@ class TestLoadBalancerFlows(base.TestCase):
         self._test_get_failover_LB_flow_no_amps_act_stdby([amphora_dict,
                                                            amphora2_dict])
 
+    @mock.patch('octavia.common.rpc.NOTIFIER',
+                new_callable=MockNOTIFIER)
     def test_get_failover_LB_flow_two_amps_standalone_act_stdby(
-            self, mock_get_net_driver):
+            self, mock_get_net_driver, mock_notifier):
         amphora_dict = {constants.ID: uuidutils.generate_uuid(),
                         constants.ROLE: constants.ROLE_STANDALONE,
                         constants.COMPUTE_ID: uuidutils.generate_uuid(),
