@@ -45,6 +45,7 @@ class TestAllowedAddressPairsDriver(base.TestCase):
     NETWORK_ID_2 = "10"
     IP_ADDRESS_1 = "10.0.0.2"
     IP_ADDRESS_2 = "12.0.0.2"
+    IPV6_ADDRESS_1 = "2001:db8::1234"
     AMPHORA_ID = "1"
     LB_ID = "2"
     COMPUTE_ID = "3"
@@ -459,6 +460,35 @@ class TestAllowedAddressPairsDriver(base.TestCase):
                           lb, lb.vip, lb.amphorae[0], subnet)
         self.driver.neutron_client.delete_port.assert_called_once()
 
+    def test_plug_aap_port_with_add_vips(self):
+        additional_vips = [
+            {'ip_address': t_constants.MOCK_IP_ADDRESS2,
+             'subnet_id': t_constants.MOCK_VIP_SUBNET_ID2}
+        ]
+        lb = dmh.generate_load_balancer_tree(additional_vips=additional_vips)
+
+        subnet = network_models.Subnet(id=t_constants.MOCK_VIP_SUBNET_ID,
+                                       network_id=t_constants.MOCK_VIP_NET_ID)
+
+        list_ports = self.driver.neutron_client.list_ports
+        port1 = t_constants.MOCK_MANAGEMENT_PORT1['port']
+        port2 = t_constants.MOCK_MANAGEMENT_PORT2['port']
+        list_ports.side_effect = [{'ports': [port1]}, {'ports': [port2]}]
+        network_attach = self.driver.compute.attach_network_or_port
+        network_attach.side_effect = [t_constants.MOCK_VRRP_INTERFACE1]
+        update_port = self.driver.neutron_client.update_port
+        amp = self.driver.plug_aap_port(lb, lb.vip, lb.amphorae[0], subnet)
+        expected_aap = {
+            'port': {
+                'allowed_address_pairs':
+                    [{'ip_address': lb.vip.ip_address},
+                     {'ip_address': lb.additional_vips[0].ip_address}]}}
+
+        update_port.assert_any_call(amp.vrrp_port_id, expected_aap)
+        self.assertIn(amp.vrrp_ip, [t_constants.MOCK_VRRP_IP1,
+                                    t_constants.MOCK_VRRP_IP2])
+        self.assertEqual(lb.vip.ip_address, amp.ha_ip)
+
     def _set_safely(self, obj, name, value):
         if isinstance(obj, dict):
             current = obj.get(name)
@@ -535,12 +565,13 @@ class TestAllowedAddressPairsDriver(base.TestCase):
             network_id=t_constants.MOCK_NETWORK_ID,
             ip_address=t_constants.MOCK_IP_ADDRESS)
         fake_lb = data_models.LoadBalancer(id='1', vip=fake_lb_vip)
-        vip = self.driver.allocate_vip(fake_lb)
+        vip, additional_vips = self.driver.allocate_vip(fake_lb)
         self.assertIsInstance(vip, data_models.Vip)
         self.assertEqual(t_constants.MOCK_IP_ADDRESS, vip.ip_address)
         self.assertEqual(t_constants.MOCK_SUBNET_ID, vip.subnet_id)
         self.assertEqual(t_constants.MOCK_PORT_ID, vip.port_id)
         self.assertEqual(fake_lb.id, vip.load_balancer_id)
+        self.assertFalse(additional_vips)
 
     @mock.patch('octavia.network.drivers.neutron.base.BaseNeutronDriver.'
                 '_check_extension_enabled', return_value=True)
@@ -568,7 +599,7 @@ class TestAllowedAddressPairsDriver(base.TestCase):
                                       octavia_owned=True)
         fake_lb = data_models.LoadBalancer(id='1', vip=fake_lb_vip,
                                            project_id='test-project')
-        vip = self.driver.allocate_vip(fake_lb)
+        vip, additional_vips = self.driver.allocate_vip(fake_lb)
         exp_create_port_call = {
             'port': {
                 'name': 'octavia-lb-1',
@@ -588,6 +619,7 @@ class TestAllowedAddressPairsDriver(base.TestCase):
         self.assertEqual(t_constants.MOCK_SUBNET_ID, vip.subnet_id)
         self.assertEqual(t_constants.MOCK_PORT_ID, vip.port_id)
         self.assertEqual(fake_lb.id, vip.load_balancer_id)
+        self.assertFalse(additional_vips)
 
     @mock.patch('octavia.network.drivers.neutron.base.BaseNeutronDriver.'
                 'get_port', side_effect=network_base.PortNotFound)
@@ -611,7 +643,7 @@ class TestAllowedAddressPairsDriver(base.TestCase):
                                       port_id=t_constants.MOCK_PORT_ID)
         fake_lb = data_models.LoadBalancer(id='1', vip=fake_lb_vip,
                                            project_id='test-project')
-        vip = self.driver.allocate_vip(fake_lb)
+        vip, additional_vips = self.driver.allocate_vip(fake_lb)
         exp_create_port_call = {
             'port': {
                 'name': 'octavia-lb-1',
@@ -629,6 +661,7 @@ class TestAllowedAddressPairsDriver(base.TestCase):
         self.assertEqual(t_constants.MOCK_SUBNET_ID, vip.subnet_id)
         self.assertEqual(t_constants.MOCK_PORT_ID, vip.port_id)
         self.assertEqual(fake_lb.id, vip.load_balancer_id)
+        self.assertFalse(additional_vips)
 
     @mock.patch('octavia.network.drivers.neutron.base.BaseNeutronDriver.'
                 'get_port', side_effect=Exception('boom'))
@@ -668,10 +701,11 @@ class TestAllowedAddressPairsDriver(base.TestCase):
             'network_id': t_constants.MOCK_NETWORK_ID
         }}
         fake_lb_vip = data_models.Vip(subnet_id=t_constants.MOCK_SUBNET_ID,
-                                      network_id=t_constants.MOCK_NETWORK_ID)
+                                      network_id=t_constants.MOCK_NETWORK_ID,
+                                      ip_address=t_constants.MOCK_IP_ADDRESS)
         fake_lb = data_models.LoadBalancer(id='1', vip=fake_lb_vip,
                                            project_id='test-project')
-        vip = self.driver.allocate_vip(fake_lb)
+        vip, additional_vips = self.driver.allocate_vip(fake_lb)
         exp_create_port_call = {
             'port': {
                 'name': 'octavia-lb-1',
@@ -680,7 +714,8 @@ class TestAllowedAddressPairsDriver(base.TestCase):
                 'device_owner': allowed_address_pairs.OCTAVIA_OWNER,
                 'admin_state_up': False,
                 'project_id': 'test-project',
-                'fixed_ips': [{'subnet_id': t_constants.MOCK_SUBNET_ID}]
+                'fixed_ips': [{'ip_address': t_constants.MOCK_IP_ADDRESS,
+                               'subnet_id': t_constants.MOCK_SUBNET_ID}]
             }
         }
         create_port.assert_called_once_with(exp_create_port_call)
@@ -689,6 +724,7 @@ class TestAllowedAddressPairsDriver(base.TestCase):
         self.assertEqual(t_constants.MOCK_SUBNET_ID, vip.subnet_id)
         self.assertEqual(t_constants.MOCK_PORT_ID, vip.port_id)
         self.assertEqual(fake_lb.id, vip.load_balancer_id)
+        self.assertFalse(additional_vips)
 
     @mock.patch('octavia.network.drivers.neutron.base.BaseNeutronDriver.'
                 '_check_extension_enabled', return_value=True)
@@ -709,7 +745,7 @@ class TestAllowedAddressPairsDriver(base.TestCase):
                                       ip_address=t_constants.MOCK_IP_ADDRESS)
         fake_lb = data_models.LoadBalancer(id='1', vip=fake_lb_vip,
                                            project_id='test-project')
-        vip = self.driver.allocate_vip(fake_lb)
+        vip, additional_vips = self.driver.allocate_vip(fake_lb)
         exp_create_port_call = {
             'port': {
                 'name': 'octavia-lb-1',
@@ -728,6 +764,7 @@ class TestAllowedAddressPairsDriver(base.TestCase):
         self.assertEqual(t_constants.MOCK_SUBNET_ID, vip.subnet_id)
         self.assertEqual(t_constants.MOCK_PORT_ID, vip.port_id)
         self.assertEqual(fake_lb.id, vip.load_balancer_id)
+        self.assertFalse(additional_vips)
 
     @mock.patch('octavia.network.drivers.neutron.base.BaseNeutronDriver.'
                 '_check_extension_enabled', return_value=True)
@@ -746,7 +783,7 @@ class TestAllowedAddressPairsDriver(base.TestCase):
         fake_lb_vip = data_models.Vip(network_id=t_constants.MOCK_NETWORK_ID)
         fake_lb = data_models.LoadBalancer(id='1', vip=fake_lb_vip,
                                            project_id='test-project')
-        vip = self.driver.allocate_vip(fake_lb)
+        vip, additional_vips = self.driver.allocate_vip(fake_lb)
         exp_create_port_call = {
             'port': {
                 'name': 'octavia-lb-1',
@@ -760,6 +797,7 @@ class TestAllowedAddressPairsDriver(base.TestCase):
         self.assertIsInstance(vip, data_models.Vip)
         self.assertEqual(t_constants.MOCK_PORT_ID, vip.port_id)
         self.assertEqual(fake_lb.id, vip.load_balancer_id)
+        self.assertTrue(additional_vips)
 
     @mock.patch('octavia.network.drivers.neutron.base.BaseNeutronDriver.'
                 '_check_extension_enabled', return_value=False)
@@ -776,10 +814,11 @@ class TestAllowedAddressPairsDriver(base.TestCase):
             'network_id': t_constants.MOCK_NETWORK_ID
         }}
         fake_lb_vip = data_models.Vip(subnet_id=t_constants.MOCK_SUBNET_ID,
-                                      network_id=t_constants.MOCK_NETWORK_ID)
+                                      network_id=t_constants.MOCK_NETWORK_ID,
+                                      ip_address=t_constants.MOCK_IP_ADDRESS)
         fake_lb = data_models.LoadBalancer(id='1', vip=fake_lb_vip,
                                            project_id='test-project')
-        vip = self.driver.allocate_vip(fake_lb)
+        vip, additional_vips = self.driver.allocate_vip(fake_lb)
         exp_create_port_call = {
             'port': {
                 'name': 'octavia-lb-1',
@@ -788,7 +827,8 @@ class TestAllowedAddressPairsDriver(base.TestCase):
                 'device_owner': allowed_address_pairs.OCTAVIA_OWNER,
                 'admin_state_up': False,
                 'tenant_id': 'test-project',
-                'fixed_ips': [{'subnet_id': t_constants.MOCK_SUBNET_ID}]
+                'fixed_ips': [{'ip_address': t_constants.MOCK_IP_ADDRESS,
+                               'subnet_id': t_constants.MOCK_SUBNET_ID}]
             }
         }
         create_port.assert_called_once_with(exp_create_port_call)
@@ -797,6 +837,55 @@ class TestAllowedAddressPairsDriver(base.TestCase):
         self.assertEqual(t_constants.MOCK_SUBNET_ID, vip.subnet_id)
         self.assertEqual(t_constants.MOCK_PORT_ID, vip.port_id)
         self.assertEqual(fake_lb.id, vip.load_balancer_id)
+        self.assertFalse(additional_vips)
+
+    @mock.patch('octavia.network.drivers.neutron.base.BaseNeutronDriver.'
+                '_check_extension_enabled', return_value=False)
+    def test_allocate_vip_with_additional_vips(self, mock_check_ext):
+        port_create_dict = copy.deepcopy(t_constants.MOCK_NEUTRON_PORT)
+        port_create_dict['port']['device_owner'] = (
+            allowed_address_pairs.OCTAVIA_OWNER)
+        port_create_dict['port']['device_id'] = 'lb-1'
+        create_port = self.driver.neutron_client.create_port
+        create_port.return_value = port_create_dict
+        show_subnet = self.driver.neutron_client.show_subnet
+        show_subnet.return_value = {'subnet': {
+            'id': t_constants.MOCK_SUBNET_ID,
+            'network_id': t_constants.MOCK_NETWORK_ID
+        }}
+        fake_lb_vip = data_models.Vip(subnet_id=t_constants.MOCK_SUBNET_ID,
+                                      network_id=t_constants.MOCK_NETWORK_ID,
+                                      ip_address=t_constants.MOCK_IP_ADDRESS)
+        fake_additional_vips = [
+            data_models.AdditionalVip(ip_address=t_constants.MOCK_IP_ADDRESS2),
+            data_models.AdditionalVip(subnet_id=t_constants.MOCK_SUBNET_ID3)]
+        fake_lb = data_models.LoadBalancer(
+            id='1', vip=fake_lb_vip,
+            additional_vips=fake_additional_vips,
+            project_id='test-project')
+        vip, additional_vips = self.driver.allocate_vip(fake_lb)
+        exp_create_port_call = {
+            'port': {
+                'name': 'octavia-lb-1',
+                'network_id': t_constants.MOCK_NETWORK_ID,
+                'device_id': 'lb-1',
+                'device_owner': allowed_address_pairs.OCTAVIA_OWNER,
+                'admin_state_up': False,
+                'tenant_id': 'test-project',
+                'fixed_ips': [
+                    {'ip_address': t_constants.MOCK_IP_ADDRESS,
+                     'subnet_id': t_constants.MOCK_SUBNET_ID},
+                    {'ip_address': t_constants.MOCK_IP_ADDRESS2},
+                    {'subnet_id': t_constants.MOCK_SUBNET_ID3}]
+            }
+        }
+        create_port.assert_called_once_with(exp_create_port_call)
+        self.assertIsInstance(vip, data_models.Vip)
+        self.assertEqual(t_constants.MOCK_IP_ADDRESS, vip.ip_address)
+        self.assertEqual(t_constants.MOCK_SUBNET_ID, vip.subnet_id)
+        self.assertEqual(t_constants.MOCK_PORT_ID, vip.port_id)
+        self.assertEqual(fake_lb.id, vip.load_balancer_id)
+        self.assertFalse(additional_vips)
 
     @mock.patch("time.time")
     @mock.patch("time.sleep")
@@ -1019,7 +1108,11 @@ class TestAllowedAddressPairsDriver(base.TestCase):
                      data_models.Listener(protocol_port=50, peer_port=1026,
                                           protocol=constants.PROTOCOL_UDP)]
         vip = data_models.Vip(ip_address='10.0.0.2')
-        lb = data_models.LoadBalancer(id='1', listeners=listeners, vip=vip)
+
+        additional_vip = data_models.AdditionalVip(
+            ip_address=self.IPV6_ADDRESS_1)
+        lb = data_models.LoadBalancer(id='1', listeners=listeners, vip=vip,
+                                      additional_vips=[additional_vip])
         list_sec_grps = self.driver.neutron_client.list_security_groups
         list_sec_grps.return_value = {'security_groups': [{'id': 'secgrp-1'}]}
         fake_rules = {
@@ -1348,11 +1441,17 @@ class TestAllowedAddressPairsDriver(base.TestCase):
             t_constants.MOCK_NEUTRON_PORT, t_constants.MOCK_NEUTRON_PORT,
             t_constants.MOCK_NEUTRON_PORT, t_constants.MOCK_NEUTRON_PORT,
             t_constants.MOCK_NEUTRON_PORT, t_constants.MOCK_NEUTRON_PORT,
+            t_constants.MOCK_NEUTRON_PORT, t_constants.MOCK_NEUTRON_PORT,
+            t_constants.MOCK_NEUTRON_PORT, t_constants.MOCK_NEUTRON_PORT,
             Exception('boom')]
         fake_subnet = {'subnet': {
             'id': t_constants.MOCK_SUBNET_ID,
             'gateway_ip': t_constants.MOCK_IP_ADDRESS,
             'cidr': t_constants.MOCK_CIDR}}
+        fake_subnet2 = {'subnet': {
+            'id': t_constants.MOCK_SUBNET_ID2,
+            'gateway_ip': t_constants.MOCK_IP_ADDRESS2,
+            'cidr': t_constants.MOCK_CIDR}}
         show_subnet = self.driver.neutron_client.show_subnet
         show_subnet.return_value = fake_subnet
         configs = self.driver.get_network_configs(load_balancer_mock)
@@ -1387,6 +1486,30 @@ class TestAllowedAddressPairsDriver(base.TestCase):
         self.assertEqual(expected_subnet_id, config.ha_subnet.id)
         self.assertEqual(expected_subnet_id, config.vrrp_subnet.id)
 
+        # Test with additional_vips
+        load_balancer_mock.additional_vips = [
+            data_models.AdditionalVip(
+                subnet_id=t_constants.MOCK_SUBNET_ID2,
+                ip_address=t_constants.MOCK_IP_ADDRESS2)
+        ]
+        show_subnet.side_effect = [
+            fake_subnet,
+            fake_subnet,
+            fake_subnet,
+            fake_subnet2]
+
+        configs = self.driver.get_network_configs(load_balancer_mock,
+                                                  amphora_mock)
+        self.assertEqual(1, len(configs))
+        config = configs[222]
+        self.assertEqual(t_constants.MOCK_SUBNET_ID2,
+                         config.additional_vip_data[0].subnet.id)
+        self.assertEqual(t_constants.MOCK_IP_ADDRESS2,
+                         config.additional_vip_data[0].ip_address)
+
+        show_subnet.reset_mock(side_effect=True)
+        show_subnet.return_value = fake_subnet
+
         # Test with a specific amphora
         configs = self.driver.get_network_configs(load_balancer_mock,
                                                   amphora_mock)
@@ -1606,14 +1729,15 @@ class TestAllowedAddressPairsDriver(base.TestCase):
                              'stateful': None,
                              'project_id': t_constants.MOCK_PROJECT_ID}
 
-        self.driver.neutron_client.list_security_groups.side_effect = [
+        neutron_client = self.driver.neutron_client
+        neutron_client.list_security_groups.side_effect = [
             FAKE_NEUTRON_SECURITY_GROUPS, None, Exception('boom')]
 
         self.driver.sec_grp_enabled = False
         result = self.driver.get_security_group(FAKE_SG_NAME)
 
         self.assertIsNone(result)
-        self.driver.neutron_client.list_security_groups.assert_not_called()
+        neutron_client.list_security_groups.assert_not_called()
 
         # Test successful get of the security group
         self.driver.sec_grp_enabled = True
@@ -1621,7 +1745,7 @@ class TestAllowedAddressPairsDriver(base.TestCase):
         result = self.driver.get_security_group(FAKE_SG_NAME)
 
         self.assertEqual(reference_sg_dict, result.to_dict())
-        self.driver.neutron_client.list_security_groups.called_once_with(
+        neutron_client.list_security_groups.assert_called_once_with(
             name=FAKE_SG_NAME)
 
         # Test no security groups returned
